instrumenttools.InstrumentInventory
===================================

.. abjad-lineage:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory

.. autoclass:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.append
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.count
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.extend
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.index
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.insert
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.pop
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.remove
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.reverse
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.sort
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__add__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__contains__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__delitem__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__delslice__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__getitem__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__getslice__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__iadd__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__imul__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__iter__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__len__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__mul__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__repr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__reversed__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__rmul__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__setitem__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__setslice__
   :noindex:
